@@ -8,13 +8,13 @@ my $custom_port  = 11000;
 my $custom_port1 = $custom_port + 1;
 
 ok_exec({
-command     => "make_sandbox $TEST_VERSION -- --sandbox_port=$custom_port --no_confirm",
+command     => "make_sandbox $TEST_VERSION -- --sandbox_port=$custom_port --no_confirm --master",
 expected    => 'sandbox server started',
 msg         => 'server 1 started',
 });
 
 ok_exec({
-command     => "make_sandbox $TEST_VERSION -- --sandbox_port=$custom_port --check_port --no_confirm",
+command     => "make_sandbox $TEST_VERSION -- --sandbox_port=$custom_port --check_port --no_confirm --master",
 expected    => 'sandbox server started',
 msg         => 'server 2 started',
 });
@@ -26,6 +26,13 @@ expected    => $custom_port,
 msg         => 'right port on server 1',
 });
 
+ok_sql({
+path        => "$SANDBOX_HOME/msb_${version}/",
+query       => "show variables like 'server_id'",
+expected    => $custom_port,
+msg         => 'right server_id on server 1',
+});
+
 ok_sql({
 path        => "$SANDBOX_HOME/msb_${version}_a",
 query       => "show variables like 'port'",
@@ -33,6 +40,13 @@ expected    => "$custom_port1",
 msg         => 'right port on server 2',
 });
 
+ok_sql({
+path        => "$SANDBOX_HOME/msb_${version}_a",
+query       => "show variables like 'server_id'",
+expected    => "$custom_port1",
+msg         => 'right server_id on server 2',
+});
+
 ok_exec ({
 command     => "sbtool -o delete -s $SANDBOX_HOME/msb_${version}/",
 expected    => 'has been removed',
